==> huaweicloudsdkprojectman-3.0.54-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_cur_user_role_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowCurUserRoleResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'user_role': 'int'
    }

    attribute_map = {
        'user_role': 'user_role'
    }

    def __init__(self, user_role=None):
        """ShowCurUserRoleResponse - a model defined in huaweicloud sdk"""
        
        super(ShowCurUserRoleResponse, self).__init__()

        self._user_role = None
        self.discriminator = None

        if user_role is not None:
            self.user_role = user_role

    @property
    def user_role(self):
        """Gets the user_role of this ShowCurUserRoleResponse.

        用户角色id

        :return: The user_role of this ShowCurUserRoleResponse.
        :rtype: int
        """
        return self._user_role

    @user_role.setter
    def user_role(self, user_role):
        """Sets the user_role of this ShowCurUserRoleResponse.

        用户角色id

        :param user_role: The user_role of this ShowCurUserRoleResponse.
        :type: int
        """
        self._user_role = user_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCurUserRoleResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.55-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_cur_user_role_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowCurUserRoleResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'user_role': 'int'
    }

    attribute_map = {
        'user_role': 'user_role'
    }

    def __init__(self, user_role=None):
        """ShowCurUserRoleResponse - a model defined in huaweicloud sdk"""
        
        super(ShowCurUserRoleResponse, self).__init__()

        self._user_role = None
        self.discriminator = None

        if user_role is not None:
            self.user_role = user_role

    @property
    def user_role(self):
        """Gets the user_role of this ShowCurUserRoleResponse.

        用户角色id

        :return: The user_role of this ShowCurUserRoleResponse.
        :rtype: int
        """
        return self._user_role

    @user_role.setter
    def user_role(self, user_role):
        """Sets the user_role of this ShowCurUserRoleResponse.

        用户角色id

        :param user_role: The user_role of this ShowCurUserRoleResponse.
        :type: int
        """
        self._user_role = user_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCurUserRoleResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
